<!DOCTYPE TS><TS>
<context>
    <name>AddClock</name>
    <message>
        <source>Add Log Clock</source>
        <translation>Adicionar Relógio </translation>
    </message>
    <message>
        <source>&amp;New Clock Name:</source>
        <translation>&amp;Nome do Novo Relógio:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>AddEvent</name>
    <message>
        <source>Add Log Event</source>
        <translation>Adicionar Evento</translation>
    </message>
    <message>
        <source>&amp;New Event Name:</source>
        <translation>&amp;Nome do Novo Evento</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>ClockListView</name>
    <message>
        <source>Edit Event</source>
        <translation>Editar Evento</translation>
    </message>
</context>
<context>
    <name>EditClock</name>
    <message>
        <source>Edit Clock:</source>
        <translation>Editar Relogio:</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation>Código:</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Início</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fim</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Evento</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>Count</source>
        <translation>Contador</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Deletar</translation>
    </message>
    <message>
        <source>Remarks</source>
        <translation>Observações</translation>
    </message>
    <message>
        <source>Scheduler
Rules</source>
        <translation>Regras do
Agendador</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salvar</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>&amp;Salvar 
Como</translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation>Lista de 
&amp;Serviços</translation>
    </message>
    <message>
        <source>Colo&amp;r</source>
        <translation>&amp;Cor</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation>Tem certeza que quer 
deletar</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Deletar Evento</translation>
    </message>
    <message>
        <source>Clock Modified</source>
        <translation>Relógio Modififcado</translation>
    </message>
    <message>
        <source>The clock has been modified.
Do you want to save?</source>
        <translation>O Relógio foi Modificado.
Você quer salvar?</translation>
    </message>
    <message>
        <source>Missing Clock Code</source>
        <translation>Está faltando o Código do Relógio</translation>
    </message>
    <message>
        <source>You must specify a clock code!</source>
        <translation>Você deve especificar um código para o Relógio!</translation>
    </message>
    <message>
        <source>Code Exists</source>
        <translation>Código existente:</translation>
    </message>
    <message>
        <source>The clock code is already in use!</source>
        <translation>O Código do Relógio já está em uso!</translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation>Relógio Existente</translation>
    </message>
    <message>
        <source>Clock already exists!  Overwrite?</source>
        <translation>Relógio existente!   Sobreescrever</translation>
    </message>
    <message>
        <source>--- End of clock ---</source>
        <translation>-- Fim do Relógio --</translation>
    </message>
    <message>
        <source>Invalid Code</source>
        <translation>Código Inválido</translation>
    </message>
    <message>
        <source>You must provide a clock code!</source>
        <translation>Você deve dar um código ao Relógio!</translation>
    </message>
    <message>
        <source>Duplicate Code</source>
        <translation>Código Duplicado</translation>
    </message>
    <message>
        <source>That code is already in use!</source>
        <translation>Este Código já está em uso!</translation>
    </message>
</context>
<context>
    <name>EditEvent</name>
    <message>
        <source>Editing Event</source>
        <translation>Editando Evento</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Audio Only</source>
        <translation>Somente Áudio</translation>
    </message>
    <message>
        <source>Macros Only</source>
        <translation>Somente Macros</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CARTÃO</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DURAÇÃO</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>ARTISTA</translation>
    </message>
    <message>
        <source>START</source>
        <translation>INÍCIO</translation>
    </message>
    <message>
        <source>END</source>
        <translation>TÉRMINO</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPO</translation>
    </message>
    <message>
        <source>REMARKS</source>
        <translation>OBSERVAÇÕES</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>TODOS</translation>
    </message>
    <message>
        <source>PRE-POSITION LOG</source>
        <translation>PRE-POSCIONAR LISTA</translation>
    </message>
    <message>
        <source>Cue to this event</source>
        <translation>Marcar este Evento</translation>
    </message>
    <message>
        <source>before scheduled start.  (First cart will have a STOP transition.)</source>
        <translation>antes do agendado começar.  (Primeiro Cartão terá uma transição PARE)</translation>
    </message>
    <message>
        <source>TIMED START</source>
        <translation>HORA CERTA</translation>
    </message>
    <message>
        <source>Use hard start time</source>
        <translation>Usar Hora Certa</translation>
    </message>
    <message>
        <source>Make Post Point</source>
        <translation>Fazer Marcação </translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Ação se anterior estiver sendo executada</translation>
    </message>
    <message>
        <source>Start immediately</source>
        <translation>Iniciar Imediatamente</translation>
    </message>
    <message>
        <source>Make next</source>
        <translation>Ser a Próxima</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Esperar até</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pare</translation>
    </message>
    <message>
        <source>Transition if previous event ends before start time:</source>
        <translation>Transição se evento anterior acabar antes do horário de início:</translation>
    </message>
    <message>
        <source>ENFORCING LENGTH</source>
        <translation>FORÇANDO DURAÇÃO</translation>
    </message>
    <message>
        <source>Use AutoFill</source>
        <translation>Preencher</translation>
    </message>
    <message>
        <source>Warn if fill is over or under</source>
        <translation>Avisar: Alongou ou Encurtou</translation>
    </message>
    <message>
        <source>by at least</source>
        <translation>Pelo menos</translation>
    </message>
    <message>
        <source>Use Timescaling</source>
        <translation>Usar Escala de Tempo</translation>
    </message>
    <message>
        <source>Len:</source>
        <translation>Dur:</translation>
    </message>
    <message>
        <source>TRANSITION</source>
        <translation>TRANSIÇÃO</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation>CONTADOR</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>From Traffic</source>
        <translation>Do Tráfego</translation>
    </message>
    <message>
        <source>From Music</source>
        <translation>De Músicas</translation>
    </message>
    <message>
        <source>Select from:</source>
        <translation>Selecionar de:</translation>
    </message>
    <message>
        <source>Title Separation</source>
        <translation>Separação título</translation>
    </message>
    <message>
        <source>Must have code</source>
        <translation>Deve ter código</translation>
    </message>
    <message>
        <source>Import carts scheduled</source>
        <translation>Importar Cartões Agendados</translation>
    </message>
    <message>
        <source>prior to the start of this event.</source>
        <translation>Antes do Início deste Evento.</translation>
    </message>
    <message>
        <source>after the end of this event.</source>
        <translation>Após o fim deste Evento.</translation>
    </message>
    <message>
        <source>First cart has a</source>
        <translation>Primeiro Cartão tem</translation>
    </message>
    <message>
        <source>Imported carts have a</source>
        <translation>Cartões importados têm</translation>
    </message>
    <message>
        <source>transition.</source>
        <translation>transição.</translation>
    </message>
    <message>
        <source>Import inline traffic with the</source>
        <translation>Importar Tráfego interno com</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[nenhum]</translation>
    </message>
    <message>
        <source>event.</source>
        <translation>evento.</translation>
    </message>
    <message>
        <source>POST-IMPORT CARTS</source>
        <translation>CARTÕES PÓS-IMPORTAÇÃO</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salvar</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>&amp;Salvar Como</translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation>&amp;Lista de
Serviços</translation>
    </message>
    <message>
        <source>C&amp;olor</source>
        <translation>&amp;Cor</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDControle</translation>
    </message>
    <message>
        <source>Event already exists!
Do you want to overwrite it?</source>
        <translation>Evento já Existe!
Você quer sobreescrêve-lo?</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Editar Evento</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation>Macro</translation>
    </message>
    <message>
        <source>Cue</source>
        <translation>Marca</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SOBRE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>PARE</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>SIMPLES</translation>
    </message>
    <message>
        <source>, Timed(Start)</source>
        <translation>, Hora Certa(Início)</translation>
    </message>
    <message>
        <source>, Timed(MakeNext)</source>
        <translation>,  Hora Certa(Ser Próximo)</translation>
    </message>
    <message>
        <source>Timed(Wait</source>
        <translation>Hora Certa(Esperar)</translation>
    </message>
    <message>
        <source>, Post</source>
        <translation>, Pós</translation>
    </message>
    <message>
        <source>, Fill</source>
        <translation>, Preencher</translation>
    </message>
    <message>
        <source>, Scale</source>
        <translation>, Escala</translation>
    </message>
    <message>
        <source>, Traffic</source>
        <translation>, Tráfego</translation>
    </message>
    <message>
        <source>, Music</source>
        <translation>, Música</translation>
    </message>
    <message>
        <source>, Scheduler</source>
        <translation>, Agendador</translation>
    </message>
    <message>
        <source>, Inline Traffic</source>
        <translation>, Tráfego Interno</translation>
    </message>
    <message>
        <source>PRE-IMPORT CARTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IMPORT</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEventLine</name>
    <message>
        <source>Edit Event Assignment</source>
        <translation>Editar Configuração de Evento</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Evento:</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Início:</translation>
    </message>
    <message>
        <source>End Time:</source>
        <translation>Término:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Invalid Event</source>
        <translation>Evento Inválido</translation>
    </message>
    <message>
        <source>The event end time cannot be earlier than the start time.</source>
        <translation>A hora de término do Evento não pode ser anterior à hora de início </translation>
    </message>
    <message>
        <source>No Such Event</source>
        <translation>Este Evento não Existe</translation>
    </message>
    <message>
        <source>There is no such event.</source>
        <translation>Este Evento não Existe</translation>
    </message>
    <message>
        <source>This event overlaps with an
already existing event.</source>
        <translation>Este Evento atropela um outro
evento existente.</translation>
    </message>
</context>
<context>
    <name>EditGrid</name>
    <message>
        <source>Edit Grid:</source>
        <translation>Editar Grade:</translation>
    </message>
    <message>
        <source>Edit Clock</source>
        <translation>Editar Relógio</translation>
    </message>
    <message>
        <source>Clear Hour</source>
        <translation>Limpar Hora</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Change
&amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to update ALL clocks in the grid?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This operation cannot be undone!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditNote</name>
    <message>
        <source>Edit Log Note</source>
        <translation>Editar nota de Lista</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>EditPerms</name>
    <message>
        <source>Service Associations</source>
        <translation>Associacoes de Servicos</translation>
    </message>
    <message>
        <source>Available Services</source>
        <translation>Serviços Disponíveis</translation>
    </message>
    <message>
        <source>Enabled Services</source>
        <translation>Serviços Habilitados</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>EditSchedRules</name>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>CODE</source>
        <translation>CÓDIGO</translation>
    </message>
    <message>
        <source>MAX. IN A ROW</source>
        <translation>MAX NA SEQUÊNCIA</translation>
    </message>
    <message>
        <source>MIN. WAIT</source>
        <translation>MIN. ESPERA</translation>
    </message>
    <message>
        <source>DO NOT SCHEDULE AFTER</source>
        <translation>NÃO AGENDE DEPOIS DE</translation>
    </message>
    <message>
        <source>OR AFTER</source>
        <translation>OU APÓS</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>DESCRIÇÃO</translation>
    </message>
    <message>
        <source>Scheduler Codes:</source>
        <translation>Códigos do Agendador:</translation>
    </message>
    <message>
        <source>Rules Modified</source>
        <translation>Regras Modificadas</translation>
    </message>
    <message>
        <source>The rules have been modified.
Do you want to save?</source>
        <translation>As Regras froam modificadas.
Você quer salvar?</translation>
    </message>
    <message>
        <source>Scheduler Rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist Separation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Rules from Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation>Editar marcadores de Faixa de Voz</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>GenerateLog</name>
    <message>
        <source>Generate Log - User: </source>
        <translation>Gerar Lista - Usuário: </translation>
    </message>
    <message>
        <source>Generating Log...</source>
        <translation>Gerando Lista...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Serviço</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Data:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Sel</translation>
    </message>
    <message>
        <source>&amp;Create New Log</source>
        <translation>&amp;Criar Nova Lista</translation>
    </message>
    <message>
        <source>Merge &amp;Music</source>
        <translation>Agregar &amp;Música</translation>
    </message>
    <message>
        <source>Merge &amp;Traffic</source>
        <translation>Agregar &amp;Tráfego</translation>
    </message>
    <message>
        <source>Import Data</source>
        <translation>Importar Dados</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Merged</source>
        <translation>Agregados</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>The log for</source>
        <translation>A Lista para</translation>
    </message>
    <message>
        <source>already exists.  Recreating it
will remove any merged Music or Traffic events.

Recreate?</source>
        <translation>já Existe.  Recriando-a
removerá todos os Eventos de Tráfego e Música.

Recriar?</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Lista Existe</translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation>Esta ação também deletará</translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation>Faixas de voz associadas a esta lista.
Continue</translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation>Faixas Existentes</translation>
    </message>
    <message>
        <source>No Errors</source>
        <translation>Sem Erros</translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation>Exceções não encontradas. Parabéns. </translation>
    </message>
    <message>
        <source>already contains merged music and/or traffic data.
Remerging it will remove this data.  Remerge?</source>
        <translation>já contém dados de músicas e/ou tráfego agregados.
Re-agregar removerá estes dados.  Re-agregar? </translation>
    </message>
    <message>
        <source>Music Exists</source>
        <translation>Música Existente</translation>
    </message>
    <message>
        <source>already contains merged traffic data.  Remerging it
will remove this data.  Remerge?</source>
        <translation>já contém dados de tráfego agregados.
Re-agregar removerá estes dados.  Re-agregar? </translation>
    </message>
    <message>
        <source>Traffic Exists</source>
        <translation>Tráfego Existente</translation>
    </message>
</context>
<context>
    <name>ImportListView</name>
    <message>
        <source>Insert Log Note</source>
        <translation>Inserir nota de Lista</translation>
    </message>
    <message>
        <source>Edit Log Note</source>
        <translation>Editar nota de Lista</translation>
    </message>
    <message>
        <source>Insert Voice Track</source>
        <translation>Inserir Faixa de Voz</translation>
    </message>
    <message>
        <source>Edit Voice Track</source>
        <translation>Editar Faixa de Voz</translation>
    </message>
    <message>
        <source>Set PLAY Transition</source>
        <translation>Setar transição SIMPLES</translation>
    </message>
    <message>
        <source>Set SEGUE Transition</source>
        <translation>Setar transição SOBRE</translation>
    </message>
    <message>
        <source>Set STOP Transition</source>
        <translation>Setar transição PARE</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Deletar</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>[Log Note]</source>
        <translation>[Nota de Lista] </translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Faixa</translation>
    </message>
    <message>
        <source>[Voice Track]</source>
        <translation>[Faixa de Voz]</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>SIMPLES</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SOBRE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>PARE</translation>
    </message>
</context>
<context>
    <name>ListClocks</name>
    <message>
        <source>Log Clocks - User: </source>
        <translation>Relógios - Usuário: </translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Code</source>
        <translation>Código</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Deletar</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Renomear</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Limpar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>TODOS</translation>
    </message>
    <message>
        <source>NONE</source>
        <translation>NENHUM</translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation>Relógio Existente</translation>
    </message>
    <message>
        <source>An clock with that name already exists!</source>
        <translation>Um Relógio com este nome já existe!</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation>Tem certeza que quer 
deletar</translation>
    </message>
    <message>
        <source>Delete Clock</source>
        <translation>Deletar Relógio</translation>
    </message>
    <message>
        <source>is in use in the following grid(s):</source>
        <translation>está em uso nas seguintes grade(s): </translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation>Tem certeza que quer deletá-lo?</translation>
    </message>
    <message>
        <source>Clock In Use</source>
        <translation>Relógio em Uso</translation>
    </message>
</context>
<context>
    <name>ListEvents</name>
    <message>
        <source>Log Events - User: </source>
        <translation>Eventos - Usuário: </translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Deletar</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Renomear</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>TODOS</translation>
    </message>
    <message>
        <source>NONE</source>
        <translation>NENHUM</translation>
    </message>
    <message>
        <source>Event Exists</source>
        <translation>Evento Existente</translation>
    </message>
    <message>
        <source>An event with that name already exists!</source>
        <translation>Um Evento com este nome já existe!</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation>Tem certeza que quer 
deletar</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Deletar Evento</translation>
    </message>
    <message>
        <source>is in use in the following clocks:</source>
        <translation>está em uso nas seguintes relógio(s): </translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation>Você ainda quer deletá-lo?</translation>
    </message>
    <message>
        <source>Event In Use</source>
        <translation>Evento em Uso</translation>
    </message>
</context>
<context>
    <name>ListGrids</name>
    <message>
        <source>Log Grids</source>
        <translation>Grades</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>ListSvcs</name>
    <message>
        <source>Rivendell Services</source>
        <translation>Serviços do Rivendell</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVIÇO</translation>
    </message>
    <message>
        <source>OLDEST REPORT</source>
        <translation>RELATÓRIO MAIS VELHO</translation>
    </message>
    <message>
        <source>&amp;Generate
Reports</source>
        <translation>&amp;Gerar 
Relatórios</translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation>&amp;Remover
Dados</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[nenhum]</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogManager</source>
        <translation>RDControle</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Não foi possível conectar</translation>
    </message>
    <message>
        <source>Select an operation:</source>
        <translation>Selecionar uma operação:</translation>
    </message>
    <message>
        <source>Edit &amp;Events</source>
        <translation>Editar &amp;Eventos</translation>
    </message>
    <message>
        <source>Edit C&amp;locks</source>
        <translation>Editar &amp;Relógios</translation>
    </message>
    <message>
        <source>Edit G&amp;rids</source>
        <translation>Editar &amp;Grades</translation>
    </message>
    <message>
        <source>&amp;Generate Logs</source>
        <translation>&amp;Gerar Listas</translation>
    </message>
    <message>
        <source>Manage &amp;Reports</source>
        <translation>Gerenciar &amp;Relatórios</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>RDLogManager - User: </source>
        <translation>RDControle - Usuario: </translation>
    </message>
    <message>
        <source>RDLogEdit -- Database Skew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This version of RDLogManager is incompatible with the version installed on the server.
See your system administrator for an update!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation>Selecionar datas de Relatório</translation>
    </message>
    <message>
        <source>&amp;Report:</source>
        <translation>&amp;Relatório</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>&amp; Início:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Sel</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>&amp;Término:</translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation>&amp;Gerar 
Relatório</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Invalid Date Range</source>
        <translation>Intervalo de Datas Inválido</translation>
    </message>
    <message>
        <source>The end date cannot be earlier than the start date!</source>
        <translation>O Término não pode ser anterior à data de início!</translation>
    </message>
    <message>
        <source>This report type cannot span multiple dates!</source>
        <translation>Este tipo de relatório não pode atravessar múltiplas datas!</translation>
    </message>
    <message>
        <source>This report type cannot span multiple months!</source>
        <translation>Este tipo de relatório não pode atravessar múltiplos meses!</translation>
    </message>
    <message>
        <source>Report Complete</source>
        <translation>Relatório Completo</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="obsolete">Relatório Completo!</translation>
    </message>
    <message>
        <source>Report generated in</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameItem</name>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Name Conflict</source>
        <translation>Conflito de Nome</translation>
    </message>
    <message>
        <source>That name already exists!</source>
        <translation>Este nome nome já existe!</translation>
    </message>
</context>
<context>
    <name>SvcRec</name>
    <message>
        <source>Mo</source>
        <translation>Seg</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Ter</translation>
    </message>
    <message>
        <source>We</source>
        <translation>Qua</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Qui</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Sex</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>Sab</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Dom</translation>
    </message>
</context>
<context>
    <name>SvcRecDialog</name>
    <message>
        <source>Report Data</source>
        <translation>Dados de Relatório</translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation>&amp;Remover
Dados</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Delete Report Data</source>
        <translation>Deletar dados de Relatório</translation>
    </message>
    <message>
        <source>Are you sure you want to delete report data for</source>
        <translation>Tem certeza que quer deletar dados de relatório para</translation>
    </message>
</context>
<context>
    <name>editSchedCodeRules</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation>Código:</translation>
    </message>
    <message>
        <source>Max. in a row:</source>
        <translation>Max. na Sequência:</translation>
    </message>
    <message>
        <source>Min. wait:</source>
        <translation>Min. Espera:</translation>
    </message>
    <message>
        <source>Do not schedule after:</source>
        <translation>Não agende depois de:</translation>
    </message>
    <message>
        <source>Or after:</source>
        <translation>Ou depois de:</translation>
    </message>
    <message>
        <source>Edit Rules for Code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
